==> hyphenate-sdk-lite-3.2.3-sources.jar: com/hyphenate/EMError.java <==
/************************************************************
  *  * EaseMob CONFIDENTIAL 
  * __________________ 
  * Copyright (C) 2013-2014 EaseMob Technologies. All rights reserved. 
  *  
  * NOTICE: All information contained herein is, and remains 
  * the property of EaseMob Technologies.
  * Dissemination of this information or reproduction of this material 
  * is strictly forbidden unless prior written permission is obtained
  * from EaseMob Technologies.
  */

package com.hyphenate;

public class EMError {
    
    /**
     * \~chinese
     * 无错误
     * 
     * \~english
     * no error
     */
    public final static int EM_NO_ERROR = 0;

    /**
     * \~chinese
     * 一般错误，未细分的错误一般通过此errorcode抛出来
     * 
     * \~english
     * general error
     */
    public final static int GENERAL_ERROR = 1;
    
    /**
     * \~chinese
     * 网络异常
     * 
     * \~english
     * network isn't avaliable
     * 
     */
    public final static int NETWORK_ERROR = 2;
    
    
    /**
     * \~chinese
     * appkey不正确
     * 
     * \~english
     * app key is invalid
     */
    public final static int INVALID_APP_KEY = 100;
    /**
     * \~chinese
     * 用户id不正确
     * 
     * \~english
     * user name is invilid
     */
    public final static int INVALID_USER_NAME = 101;
    /**
     * \~chinese
     * 密码不正确
     * 
     * \~english
     * password is invilid
     */
    public final static int INVALID_PASSWORD = 102;
    
    /**
     * \~chinese
     * url不正确
     * 
     * \~english
     * url is invalid
     */
    public final static int INVALID_URL = 103;
    
    
    /**
     * \~chinese
     * 用户已登录
     * 
     * \~english
     * user has already login 
     */
    public final static int USER_ALREADY_LOGIN = 200;   
    /**
     * \~chinese
     * 用户未登录
     * 
     * \~english
     * user has not login
     */
    public final static int USER_NOT_LOGIN = 201;
    /**
     * \~chinese
     * 用户id或密码错误
     * 
     * \~english
     * user name or password is wrong
     */
    public final static int USER_AUTHENTICATION_FAILED = 202;   
    /**
     * \~chinese
     * 用户已经存在
     * 
     * \~english
     * user has already exist
     */
    public final static int USER_ALREADY_EXIST = 203;  
    /**
     * \~chinese
     * 不存在此用户
     * 
     * \~english
     * user dosn't exist
     */
    public final static int USER_NOT_FOUND = 204;        
    /**
     * \~chinese
     * 参数不合法
     * 
     * \~english
     * illegal argument
     */
    public final static int USER_ILLEGAL_ARGUMENT = 205;
    
    /**
     * \~chinese
     * 账户在另外一台设备登录
     * 
     * \~english
     * user login on another device
     */
    public final static int USER_LOGIN_ANOTHER_DEVICE = 206;          
    /**
     * \~chinese
     * 账户被删除
     * 
     * \~english
     * user was removed from server
     */
    public final static int USER_REMOVED = 207;
    /**
     * \~chinese
     * 注册失败
     * 
     * \~english
     * register was not success
     */
    public final static int USER_REG_FAILED = 208;
    /**
     * \~chinese
     * 更新用户信息失败
     * 
     * \~english
     * update user info failed
     */
    public final static int USER_UPDATEINFO_FAILED = 209;

    /**
     * \~chinese
     * 用户没有该操作权限
     * 
     * \~english
     * User has no right for this operation
     */
    public final static int USER_PERMISSION_DENIED = 210;
    
    /**
     * \~chinese
     * 绑定设备token失败
     * 
     * \~english
     * bind device token failed
     */
    public final static int USER_BINDDEVICETOKEN_FAILED = 211;
    
    /**
     * \~chinese
     * 解绑设备token失败
     * 
     * \~english
     * unbind device token failed
     */
    public final static int USER_UNBIND_DEVICETOKEN_FAILED = 212;
    
    /**
     * \~chinese
     * 无法访问到服务器
     * 
     * \~english
     * server is not reachable
     */
    public final static int SERVER_NOT_REACHABLE = 300;
    
    /**
     * \~chinese
     * 等待服务器响应超时
     * 
     * \~english
     * wait for server response timeout
     */
    public final static int SERVER_TIMEOUT = 301;
    /**
     * \~chinese
     * 服务器繁忙
     * 
     * \~english
     * server is busy
     */
    public final static int SERVER_BUSY = 302;
    
    /**
     * \~chinese
     * 未知的server异常
     * 
     * \~english
     * unknow server error
     */
    public final static int SERVER_UNKNOWN_ERROR = 303;

    /**
     * \~chinese
     * 获取dns失败
     * 
     * \~english
     * Can't get dns list
     */
    public final static int SERVER_GET_DNSLIST_FAILED = 304;

    /**
     * \~chinese
     * IM功能限制
     * 
     * \~english
     * service was restricted
     */
    public final static int SERVER_SERVICE_RESTRICTED = 305;

    /**
     * \~chinese
     * 文件不存在
     * 
     * \~english
     * file doesn't exist
     */
    public final static int FILE_NOT_FOUND = 400;
    
    /**
     * \~chinese
     * 文件不合法
     * 
     * \~english
     * invalid file
     */
    public final static int FILE_INVALID = 401;
    
    /**
     * \~chinese
     * 文件上传失败
     * 
     * \~english
     * file upload failed
     */
    public final static int FILE_UPLOAD_FAILED = 402;        
    
    /**
     * \~chinese
     * 文件下载失败
     * 
     * \~english
     * file download failed
     */
    public final static int FILE_DOWNLOAD_FAILED = 403;               
    
    /**
     * \~chinese
     * 消息不合法
     * 
     * \~english
     * invalid message
     */
    public final static int MESSAGE_INVALID = 500;
 
    /**
     * \~chinese
     * 消息内容包含非法或敏感词
     * 
     * \~english
     * message include illegal content
     */
    public final static int MESSAGE_INCLUDE_ILLEGAL_CONTENT = 501;
    /**
     * \~chinese
     * 消息发送过快，触发限流
     * 
     * \~english
     * message is sent too rapidly, triggering current limit
     */
    public final static int MESSAGE_SEND_TRAFFIC_LIMIT = 502;
    /**
     * \~chinese
     * 消息加解密错误
     * 
     * \~english
     * message encrpt error
     */
    public final static int MESSAGE_ENCRYPTION_ERROR = 503;
    
    /**
     * \~chinese
     * 群id不正确
     * 
     * \~english
     * invalid group id
     */
    public final static int GROUP_INVALID_ID = 600;     
    /**
     * \~chinese
     * 已经加入的群组
     * 
     * \~english
     * already joined group
     */
    public final static int GROUP_ALREADY_JOINED = 601;
    /**
     * \~chinese
     * 尚未加入此群组
     * 
     * \~english
     * user has not joined the group
     */
    public final static int GROUP_NOT_JOINED = 602;
    /**
     * \~chinese
     * 群组权限不够
     * 
     * \~english
     * user has no right for this operation
     */
    public final static int GROUP_PERMISSION_DENIED = 603;      
    /**
     * \~chinese
     * 群成员已满
     * 
     * \~english
     * group members is full
     */
    public final static int GROUP_MEMBERS_FULL = 604;
    
    /**
     * \~chinese
     * 群组不存在
     * 
     * \~english
     * group dosen't exist
     */
    public final static int GROUP_NOT_EXIST = 605;
    
    /**
     * \~chinese
     * 聊天室id不正确
     * 
     * \~english
     * invalid chatroom id
     */
    public final static int CHATROOM_INVALID_ID = 700;
    /**
     * \~chinese
     * 已经在此聊天室里
     * 
     * \~english
     * user has already joined the chatroom
     */
    public final static int CHATROOM_ALREADY_JOINED = 701;
    /**
     * \~chinese
     * 尚未加入此聊天室
     * \~english
     * user has not joined the chatroom
     */
    public final static int CHATROOM_NOT_JOINED = 702;
    /**
     * \~chinese
     * 聊天室权限不够
     * \~english
     * user has no right for this operation
     */
    public final static int CHATROOM_PERMISSION_DENIED = 703;
    /**
     * \~chinese
     * 聊天室成员已满
     * 
     * \~english
     * chatroom members is full
     */
    public final static int CHATROOM_MEMBERS_FULL = 704;
    
    /**
     * \~chinese
     * 聊天室不存在
     * 
     * \~english
     * chatroom doesn't exist
     */
    public final static int CHATROOM_NOT_EXIST = 705;
    
    /**
     * \~chinese
     * 
     * 
     * \~english
     */
    public final static int CALL_INVALID_ID = 800;
    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_BUSY = 801;
    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_REMOTE_OFFLINE = 802;
    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_CONNECTION_ERROR = 803;
    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_INVALID_CAMERA_INDEX = 804;
}

==> hyphenate-sdk-lite-3.3.1-sources.jar: com/hyphenate/EMError.java <==
/*
 *  * EaseMob CONFIDENTIAL
 * __________________
 * Copyright (C) 2017 EaseMob Technologies. All rights reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of EaseMob Technologies.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from EaseMob Technologies.
 */
package com.hyphenate;

public class EMError {
    
    /**
     * \~chinese
     * 无错误
     * 
     * \~english
     * no error
     */
    public final static int EM_NO_ERROR = 0;


    /**
     * \~chinese
     * 一般错误，未细分的错误一般通过此errorcode抛出来
     * 
     * \~english
     * general error
     */
    public final static int GENERAL_ERROR = 1;
    
    /**
     * \~chinese
     * 网络异常
     * 
     * \~english
     * network not available
     * 
     */
    public final static int NETWORK_ERROR = 2;


    /**
     * \~chinese
     * appkey不正确
     * 
     * \~english
     * app key is invalid
     */
    public final static int INVALID_APP_KEY = 100;

    /**
     * \~chinese
     * 用户id不正确
     * 
     * \~english
     * username is invalid
     */
    public final static int INVALID_USER_NAME = 101;

    /**
     * \~chinese
     * 密码不正确
     * 
     * \~english
     * password is invalid
     */
    public final static int INVALID_PASSWORD = 102;
    
    /**
     * \~chinese
     * url不正确
     * 
     * \~english
     * url is invalid
     */
    public final static int INVALID_URL = 103;


    /**
     * \~chinese
     * 用户已登录
     * 
     * \~english
     * user already login
     */
    public final static int USER_ALREADY_LOGIN = 200;

    /**
     * \~chinese
     * 用户未登录
     * 
     * \~english
     * user has not login
     */
    public final static int USER_NOT_LOGIN = 201;

    /**
     * \~chinese
     * 用户id或密码错误
     * 
     * \~english
     * username or password is wrong
     */
    public final static int USER_AUTHENTICATION_FAILED = 202;

    /**
     * \~chinese
     * 用户已经存在
     * 
     * \~english
     * user already exist
     */
    public final static int USER_ALREADY_EXIST = 203;

    /**
     * \~chinese
     * 不存在此用户
     * 
     * \~english
     * user does not exist
     */
    public final static int USER_NOT_FOUND = 204;

    /**
     * \~chinese
     * 参数不合法
     * 
     * \~english
     * illegal argument
     */
    public final static int USER_ILLEGAL_ARGUMENT = 205;
    
    /**
     * \~chinese
     * 账户在另外一台设备登录
     * 
     * \~english
     * user already logged on in another device
     */
    public final static int USER_LOGIN_ANOTHER_DEVICE = 206;

    /**
     * \~chinese
     * 账户被删除
     * 
     * \~english
     * user has been removed from server
     */
    public final static int USER_REMOVED = 207;

    /**
     * \~chinese
     * 注册失败
     * 
     * \~english
     * registration failed
     */
    public final static int USER_REG_FAILED = 208;

    /**
     * \~chinese
     * 更新用户信息失败
     * 
     * \~english
     * update user info failed
     */
    public final static int USER_UPDATEINFO_FAILED = 209;

    /**
     * \~chinese
     * 用户没有该操作权限
     * 
     * \~english
     * user has no permission for the operation
     */
    public final static int USER_PERMISSION_DENIED = 210;
    
    /**
     * \~chinese
     * 绑定设备token失败
     * 
     * \~english
     * device token binding failed
     */
    public final static int USER_BINDDEVICETOKEN_FAILED = 211;
    
    /**
     * \~chinese
     * 解绑设备token失败
     * 
     * \~english
     * device token unbinding failed
     */
    public final static int USER_UNBIND_DEVICETOKEN_FAILED = 212;


    /**
     * \~chinese
     * 无法访问到服务器
     * 
     * \~english
     * server is not reachable
     */
    public final static int SERVER_NOT_REACHABLE = 300;
    
    /**
     * \~chinese
     * 等待服务器响应超时
     * 
     * \~english
     * waiting for server response timeout
     */
    public final static int SERVER_TIMEOUT = 301;

    /**
     * \~chinese
     * 服务器繁忙
     * 
     * \~english
     * server is busy
     */
    public final static int SERVER_BUSY = 302;
    
    /**
     * \~chinese
     * 未知的server异常
     * 
     * \~english
     * unknown server error
     */
    public final static int SERVER_UNKNOWN_ERROR = 303;

    /**
     * \~chinese
     * 获取dns失败
     * 
     * \~english
     * get DNS list failed
     */
    public final static int SERVER_GET_DNSLIST_FAILED = 304;

    /**
     * \~chinese
     * IM功能限制
     * 
     * \~english
     * service is restricted
     */
    public final static int SERVER_SERVICE_RESTRICTED = 305;


    /**
     * \~chinese
     * 文件不存在
     * 
     * \~english
     * file does not exist
     */
    public final static int FILE_NOT_FOUND = 400;
    
    /**
     * \~chinese
     * 文件不合法
     * 
     * \~english
     * invalid file
     */
    public final static int FILE_INVALID = 401;
    
    /**
     * \~chinese
     * 文件上传失败
     * 
     * \~english
     * file uploading failed
     */
    public final static int FILE_UPLOAD_FAILED = 402;        
    
    /**
     * \~chinese
     * 文件下载失败
     * 
     * \~english
     * file downloading failed
     */
    public final static int FILE_DOWNLOAD_FAILED = 403;               


    /**
     * \~chinese
     * 消息不合法
     * 
     * \~english
     * invalid message
     */
    public final static int MESSAGE_INVALID = 500;
 
    /**
     * \~chinese
     * 消息内容包含非法或敏感词
     * 
     * \~english
     * message include illegal content
     */
    public final static int MESSAGE_INCLUDE_ILLEGAL_CONTENT = 501;

    /**
     * \~chinese
     * 消息发送过快，触发限流
     * 
     * \~english
     * message is sent too rapidly, triggering rate limit
     */
    public final static int MESSAGE_SEND_TRAFFIC_LIMIT = 502;

    /**
     * \~chinese
     * 消息加解密错误
     * 
     * \~english
     * message encryption error
     */
    public final static int MESSAGE_ENCRYPTION_ERROR = 503;


    /**
     * \~chinese
     * 群id不正确
     * 
     * \~english
     * invalid group id
     */
    public final static int GROUP_INVALID_ID = 600;     
    /**
     * \~chinese
     * 已经加入的群组
     * 
     * \~english
     * already joined group
     */
    public final static int GROUP_ALREADY_JOINED = 601;
    /**
     * \~chinese
     * 尚未加入此群组
     * 
     * \~english
     * user has not joined the group
     */
    public final static int GROUP_NOT_JOINED = 602;
    /**
     * \~chinese
     * 群组权限不够
     * 
     * \~english
     * user has no permission for the operation
     */
    public final static int GROUP_PERMISSION_DENIED = 603;      
    /**
     * \~chinese
     * 群成员已满
     * 
     * \~english
     * group capacity reached
     */
    public final static int GROUP_MEMBERS_FULL = 604;
    
    /**
     * \~chinese
     * 群组不存在
     * 
     * \~english
     * group does not exist
     */
    public final static int GROUP_NOT_EXIST = 605;


    /**
     * \~chinese
     * 聊天室id不正确
     * 
     * \~english
     * invalid chatroom id
     */
    public final static int CHATROOM_INVALID_ID = 700;

    /**
     * \~chinese
     * 已经在此聊天室里
     * 
     * \~english
     * user already joined the chatroom
     */
    public final static int CHATROOM_ALREADY_JOINED = 701;

    /**
     * \~chinese
     * 尚未加入此聊天室
     * \~english
     * user has not joined the chatroom
     */
    public final static int CHATROOM_NOT_JOINED = 702;

    /**
     * \~chinese
     * 聊天室权限不够
     * \~english
     * user has no permission for the operation
     */
    public final static int CHATROOM_PERMISSION_DENIED = 703;

    /**
     * \~chinese
     * 聊天室成员已满
     * 
     * \~english
     * chatroom capacity reached
     */
    public final static int CHATROOM_MEMBERS_FULL = 704;
    
    /**
     * \~chinese
     * 聊天室不存在
     * 
     * \~english
     * chatroom does not exist
     */
    public final static int CHATROOM_NOT_EXIST = 705;


    /**
     * \~chinese
     * 
     * 
     * \~english
     */
    public final static int CALL_INVALID_ID = 800;

    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_BUSY = 801;

    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_REMOTE_OFFLINE = 802;

    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_CONNECTION_ERROR = 803;

    /**
     * \~chinese
     * 
     * \~english
     */
    public final static int CALL_INVALID_CAMERA_INDEX = 804;
}
